#ifndef HARKIO_VERSION_HPP_
#define HARKIO_VERSION_HPP_

#include <string>
#include <boost/operators.hpp>

/** @file Version.hpp
 * @brief Version class definition.
 */

namespace harkio2
{

/** @brief Common version number class.
 * This class represents a version number which consists of
 * major_ and minor_ version number, such as "1.2".
 */
class Version :
    private boost::totally_ordered<Version> // for !=, >, <=, >= operators
{
public:
    /** @brief Constructs version number 'major_.minor_'.
     * @param major_ The major_ version number
     * @param minor_ The minor_ version number
     */
    Version(unsigned int major_, unsigned int minor_);

    /** @brief Get major_ version number.
     */
    unsigned int GetMajor() const { return major_; }

    /** @brief Get minor_ version number.
     */
    unsigned int GetMinor() const { return minor_; }

    /** @brief Checks whether this version equals given version.
     */
    bool operator ==(const Version& rhs) const;

    /** @brief Checks whether this version is less than given version.
     */
    bool operator <(const Version& rhs) const;

    /** @brief Generate a string representing this version.
     * When this version is (X, Y), returns "X.Y".
     * @return version number
     */
    std::string ToString() const;

private:
    unsigned int major_, minor_;
};

}

#endif // HARKIO_VERSION_HPP_

