#ifndef HARKIO_HARKCONFIG_MIC_HPP_
#define HARKIO_HARKCONFIG_MIC_HPP_

#include <harkio2/defineitem.hpp>
#include <harkio2/Position.hpp>
#include <glibmm/ustring.h>

/** @file Mic.hpp
 * @brief Mic class and subclasses definitions.
 */

namespace harkio2
{
namespace harkconfig
{

/** @brief A microphone information.
 * This class specifies information about a microphone of a microphone array.
 */
class Mic
{
public:
    virtual ~Mic() {}

    /** @brief Returns the data structure version.
     * Returns the version which this instance actually represents.
     * @return The version of this structure.
     */
    virtual unsigned int GetVersion() const = 0;
};

/** @brief A sound source information version 1.
 */
class Mic1 : public Mic
{
public:
    /** @brief Returns the mic version.
     * @return The version which this class represents.
     */
    virtual unsigned int GetVersion() const { return 1; }

    /// @brief The index number of this microphone.
    DEFINE_ITEM(micIndex, unsigned int, MicIndex, unsigned int)

    /// @brief The position of this microphone.
    DEFINE_ITEM(position, harkio2::Position<float>, Position, const harkio2::Position<float>&)

    /// @brief A comment.
    DEFINE_ITEM(comment, Glib::ustring, Comment, const Glib::ustring&)

};

}
}

#endif // HARKIO_HARKCONFIG_MIC_HPP_

